@@ -12,7 +12,7 @@ Usage::
     ```
 """
 import sys
-from typing import Any, Dict, List
+from typing import Any, Dict, List, Mapping, Sequence
 
 from .literals import (
     GroupConfigurationStatusType,
@@ -93,8 +93,8 @@ _OptionalCreateGroupInputRequestTypeDef = TypedDict(
     {
         "Description": str,
         "ResourceQuery": "ResourceQueryTypeDef",
-        "Tags": Dict[str, str],
-        "Configuration": List["GroupConfigurationItemTypeDef"],
+        "Tags": Mapping[str, str],
+        "Configuration": Sequence["GroupConfigurationItemTypeDef"],
     },
     total=False,
 )
@@ -219,7 +219,7 @@ _RequiredGroupConfigurationItemTypeDef = TypedDict(
 _OptionalGroupConfigurationItemTypeDef = TypedDict(
     "_OptionalGroupConfigurationItemTypeDef",
     {
-        "Parameters": List["GroupConfigurationParameterTypeDef"],
+        "Parameters": Sequence["GroupConfigurationParameterTypeDef"],
     },
     total=False,
 )
@@ -240,7 +240,7 @@ _RequiredGroupConfigurationParameterTypeDef = TypedDict(
 _OptionalGroupConfigurationParameterTypeDef = TypedDict(
     "_OptionalGroupConfigurationParameterTypeDef",
     {
-        "Values": List[str],
+        "Values": Sequence[str],
     },
     total=False,
 )
@@ -267,7 +267,7 @@ GroupFilterTypeDef = TypedDict(
     "GroupFilterTypeDef",
     {
         "Name": GroupFilterNameType,
-        "Values": List[str],
+        "Values": Sequence[str],
     },
 )
 
@@ -292,7 +292,7 @@ GroupResourcesInputRequestTypeDef = TypedDict(
     "GroupResourcesInputRequestTypeDef",
     {
         "Group": str,
-        "ResourceArns": List[str],
+        "ResourceArns": Sequence[str],
     },
 )
 
@@ -331,7 +331,7 @@ ListGroupResourcesInputRequestTypeDef = TypedDict(
     {
         "GroupName": str,
         "Group": str,
-        "Filters": List["ResourceFilterTypeDef"],
+        "Filters": Sequence["ResourceFilterTypeDef"],
         "MaxResults": int,
         "NextToken": str,
     },
@@ -361,7 +361,7 @@ ListGroupResourcesOutputTypeDef = TypedDict(
 ListGroupsInputRequestTypeDef = TypedDict(
     "ListGroupsInputRequestTypeDef",
     {
-        "Filters": List["GroupFilterTypeDef"],
+        "Filters": Sequence["GroupFilterTypeDef"],
         "MaxResults": int,
         "NextToken": str,
     },
@@ -400,7 +400,7 @@ PutGroupConfigurationInputRequestTypeDef = TypedDict(
     "PutGroupConfigurationInputRequestTypeDef",
     {
         "Group": str,
-        "Configuration": List["GroupConfigurationItemTypeDef"],
+        "Configuration": Sequence["GroupConfigurationItemTypeDef"],
     },
     total=False,
 )
@@ -418,7 +418,7 @@ ResourceFilterTypeDef = TypedDict(
     "ResourceFilterTypeDef",
     {
         "Name": Literal["resource-type"],
-        "Values": List[str],
+        "Values": Sequence[str],
     },
 )
 
@@ -494,7 +494,7 @@ TagInputRequestTypeDef = TypedDict(
     "TagInputRequestTypeDef",
     {
         "Arn": str,
-        "Tags": Dict[str, str],
+        "Tags": Mapping[str, str],
     },
 )
 
@@ -511,7 +511,7 @@ UngroupResourcesInputRequestTypeDef = TypedDict(
     "UngroupResourcesInputRequestTypeDef",
     {
         "Group": str,
-        "ResourceArns": List[str],
+        "ResourceArns": Sequence[str],
     },
 )
 
@@ -529,7 +529,7 @@ UntagInputRequestTypeDef = TypedDict(
     "UntagInputRequestTypeDef",
     {
         "Arn": str,
-        "Keys": List[str],
+        "Keys": Sequence[str],
     },
 )
 
